# Reflex-Icons
 This library provides all icons of React-icons wrapped for ReFlex framework

## Installation
```
pip install reflex-icons
```

## Upgradation
```
pip install reflex-icons --upgrade
```

## Add react-icons in rxconfig.py
```python
frontend_packages=[
        "react-icons",
    ]
```
## Use
```python
import reflex as rx
from reflex_icons.BootStrap import BsFill0CircleFill

def index():
    return pc.box(
        BsFill0CircleFill()
    )
```



#### [📖 View all Icons ](https://react-icons.github.io/react-icons)


## Author

<b>Name :</b> Saurabh Wadekar<br>
<b>Email :</b> saurabhwadekar420@gmail.com<br>
<b>County :</b> 🇮🇳INDIA🇮🇳<br>

<h1>❤️ THANK YOU ❤️</h1><br> 
<h3>If this library is useful to you, don't forget to <b>Star ⭐</b> it</h3>


